@@ -181,9 +181,9 @@ class ProjectSettingsDialog():
 
         # presets
         self.audio_presets = AudioPresetManager()
-        self.audio_presets.load()
+        self.audio_presets.loadAll()
         self.video_presets = VideoPresetManager()
-        self.video_presets.load()
+        self.video_presets.loadAll()
 
         self._fillPresetsTreeview(
                 self.audio_preset_treeview, self.audio_presets,
@@ -232,6 +232,9 @@ class ProjectSettingsDialog():
 
         self.updateUI()
 
+        self.createAudioNoPreset(self.audio_presets)
+        self.createVideoNoPreset(self.video_presets)
+
     def bindPar(self, mgr):
 
         def updatePar(value):
@@ -283,6 +286,21 @@ class ProjectSettingsDialog():
             mgr, update_buttons_func)
         treeview.connect("focus-out-event", self._treeviewDefocusedCb, mgr)
 
+    def createAudioNoPreset(self, mgr):
+        mgr.prependPreset(_("No preset"), {
+            "depth": int(get_combo_value(self.sample_depth_combo)),
+            "channels": int(get_combo_value(self.channels_combo)),
+            "sample-rate": int(get_combo_value(self.sample_rate_combo))})
+
+    def createVideoNoPreset(self, mgr):
+        mgr.prependPreset(_("No preset"), {
+            "par": gst.Fraction(int(get_combo_value(self.par_combo).num),
+                                    int(get_combo_value(self.par_combo).denom)),
+            "frame-rate": gst.Fraction(int(get_combo_value(self.frame_rate_combo).num),
+                            int(get_combo_value(self.frame_rate_combo).denom)),
+            "height": int(self.height_spinbutton.get_value()),
+            "width": int(self.width_spinbutton.get_value())})
+
     def _newPresetCb(self, model, path, iter_, column, renderer, treeview):
         """Handle the addition of a preset to the model of the preset manager.
         """
@@ -410,10 +428,10 @@ class ProjectSettingsDialog():
         """Get a unique name for a new preset for the specified PresetManager.
         """
         existing_preset_names = list(mgr.getPresetNames())
-        preset_name = _("New Preset")
+        preset_name = _("New preset")
         i = 1
         while preset_name in existing_preset_names:
-            preset_name = _("New Preset %d") % i
+            preset_name = _("New preset %d") % i
             i += 1
         return preset_name
 
@@ -436,6 +454,7 @@ class ProjectSettingsDialog():
     def _saveAudioPresetButtonClickedCb(self, button):
         self.audio_presets.savePreset()
         self.save_audio_preset_button.set_sensitive(False)
+        self.remove_audio_preset_button.set_sensitive(True)
 
     def _addVideoPresetButtonClickedCb(self, button):
         preset_name = self._getUniquePresetName(self.video_presets)
@@ -457,24 +476,23 @@ class ProjectSettingsDialog():
     def _saveVideoPresetButtonClickedCb(self, button):
         self.video_presets.savePreset()
         self.save_video_preset_button.set_sensitive(False)
+        self.remove_video_preset_button.set_sensitive(True)
 
     def _updateAudioPresetButtons(self):
-        preset_changed = self.audio_presets.isCurrentPresetChanged()
-        self.save_audio_preset_button.set_sensitive(preset_changed)
-        preset_selected = bool(self.audio_presets.cur_preset)
-        self.remove_audio_preset_button.set_sensitive(preset_selected)
+        can_save = self.audio_presets.isSaveButtonSensitive()
+        self.save_audio_preset_button.set_sensitive(can_save)
+        can_remove = self.audio_presets.isRemoveButtonSensitive()
+        self.remove_audio_preset_button.set_sensitive(can_remove)
 
     def _updateVideoPresetButtons(self):
-        preset_changed = self.video_presets.isCurrentPresetChanged()
-        self.save_video_preset_button.set_sensitive(preset_changed)
-        preset_selected = bool(self.video_presets.cur_preset)
-        self.remove_video_preset_button.set_sensitive(preset_selected)
+        self.save_video_preset_button.set_sensitive(self.video_presets.isSaveButtonSensitive())
+        self.remove_video_preset_button.set_sensitive(self.video_presets.isRemoveButtonSensitive())
 
     def _updateAudioSaveButton(self, unused_in, button):
-        button.set_sensitive(self.audio_presets.isCurrentPresetChanged())
+        button.set_sensitive(self.audio_presets.isSaveButtonSensitive())
 
     def _updateVideoSaveButton(self, unused_in, button):
-        button.set_sensitive(self.video_presets.isCurrentPresetChanged())
+        button.set_sensitive(self.video_presets.isSaveButtonSensitive())
 
     def darSelected(self):
         return self.select_dar_radiobutton.props.active
@@ -544,7 +562,7 @@ class ProjectSettingsDialog():
     def updateMetadata(self):
         self.project.name = self.title_entry.get_text()
         self.project.author = self.author_entry.get_text()
-        self.project.year = str(self.year_spinbutton.get_adjustment().get_value())
+        self.project.year = str(self.year_spinbutton.get_value_as_int())
 
     def updateSettings(self):
         width = int(self.width_spinbutton.get_value())
@@ -565,6 +583,4 @@ class ProjectSettingsDialog():
         if response == gtk.RESPONSE_OK:
             self.updateSettings()
             self.updateMetadata()
-        self.audio_presets.save()
-        self.video_presets.save()
         self.window.destroy()
